@@ -81,6 +81,20 @@ RESPONSE_WITHOUT_FAILURES = {
         }
     ],
 }
+RESPONSE_WITHOUT_NAME = {
+    "failures": [],
+    "tasks": [
+        {
+            "containers": [],
+            "desiredStatus": "RUNNING",
+            "lastStatus": "PENDING",
+            "taskArn": f"arn:aws:ecs:us-east-1:012345678910:task/{TASK_ID}",
+            "taskDefinitionArn": "arn:aws:ecs:us-east-1:012345678910:task-definition/hello_world:11",
+        }
+    ],
+}
+
+
 WAITERS_TEST_CASES = [
     pytest.param(None, None, id="default-values"),
     pytest.param(3.14, None, id="set-delay-only"),
@@ -455,12 +469,12 @@ class TestEcsRunTaskOperator(EcsBaseTestCase):
             "tasks": [{"containers": [{"name": "foo", "lastStatus": "STOPPED", "exitCode": 1}]}]
         }
 
-        with pytest.raises(Exception) as ctx:
+        with pytest.raises(
+            Exception,
+            match="This task is not in success state - last 10 logs from Cloudwatch:\n1\n2\n3\n4\n5",
+        ):
             self.ecs._check_success_task()
 
-        assert str(ctx.value) == (
-            "This task is not in success state - last 10 logs from Cloudwatch:\n1\n2\n3\n4\n5"
-        )
         client_mock.describe_tasks.assert_called_once_with(cluster="c", tasks=["arn"])
 
     @mock.patch.object(EcsBaseOperator, "client")
@@ -474,10 +488,11 @@ class TestEcsRunTaskOperator(EcsBaseTestCase):
             "tasks": [{"containers": [{"name": "foo", "lastStatus": "STOPPED", "exitCode": 1}]}]
         }
 
-        with pytest.raises(Exception) as ctx:
+        with pytest.raises(
+            Exception, match="This task is not in success state - last 10 logs from Cloudwatch:\n"
+        ):
             self.ecs._check_success_task()
 
-        assert str(ctx.value) == "This task is not in success state - last 10 logs from Cloudwatch:\n"
         client_mock.describe_tasks.assert_called_once_with(cluster="c", tasks=["arn"])
 
     @mock.patch.object(EcsBaseOperator, "client")
@@ -488,13 +503,12 @@ class TestEcsRunTaskOperator(EcsBaseTestCase):
             "tasks": [{"containers": [{"name": "foo", "lastStatus": "STOPPED", "exitCode": 1}]}]
         }
 
-        with pytest.raises(Exception) as ctx:
+        with pytest.raises(
+            Exception,
+            match=r"This task is not in success state .*'name': 'foo'.*'lastStatus': 'STOPPED'.*'exitCode': 1",
+        ):
             self.ecs._check_success_task()
 
-        assert "This task is not in success state " in str(ctx.value)
-        assert "'name': 'foo'" in str(ctx.value)
-        assert "'lastStatus': 'STOPPED'" in str(ctx.value)
-        assert "'exitCode': 1" in str(ctx.value)
         client_mock.describe_tasks.assert_called_once_with(cluster="c", tasks=["arn"])
 
     @mock.patch.object(EcsBaseOperator, "client")
@@ -506,14 +520,11 @@ class TestEcsRunTaskOperator(EcsBaseTestCase):
             "tasks": [{"containers": [{"name": "foo", "lastStatus": "STOPPED"}]}]
         }
 
-        with pytest.raises(Exception) as ctx:
+        with pytest.raises(
+            Exception, match=r"This task is not in success state .*'name': 'foo'.*'lastStatus': 'STOPPED'"
+        ):
             self.ecs._check_success_task()
 
-        print(str(ctx.value))
-        assert "This task is not in success state " in str(ctx.value)
-        assert "'name': 'foo'" in str(ctx.value)
-        assert "'lastStatus': 'STOPPED'" in str(ctx.value)
-        assert "exitCode" not in str(ctx.value)
         client_mock.describe_tasks.assert_called_once_with(cluster="c", tasks=["arn"])
 
     @mock.patch.object(EcsBaseOperator, "client")
@@ -522,12 +533,10 @@ class TestEcsRunTaskOperator(EcsBaseTestCase):
         client_mock.describe_tasks.return_value = {
             "tasks": [{"containers": [{"name": "container-name", "lastStatus": "PENDING"}]}]
         }
-        with pytest.raises(Exception) as ctx:
+        with pytest.raises(
+            Exception, match=r"This task is still pending .*'name': 'container-name'.*'lastStatus': 'PENDING'"
+        ):
             self.ecs._check_success_task()
-        # Ordering of str(dict) is not guaranteed.
-        assert "This task is still pending " in str(ctx.value)
-        assert "'name': 'container-name'" in str(ctx.value)
-        assert "'lastStatus': 'PENDING'" in str(ctx.value)
         client_mock.describe_tasks.assert_called_once_with(cluster="c", tasks=["arn"])
 
     @mock.patch.object(EcsBaseOperator, "client")
@@ -788,6 +797,54 @@ class TestEcsRunTaskOperator(EcsBaseTestCase):
 
         assert self.ecs._get_logs_stream_name().startswith(f"{prefix}/{container_name}/")
 
+    @mock.patch.object(EcsBaseOperator, "client")
+    @mock.patch("airflow.providers.amazon.aws.operators.ecs.sleep", return_value=None)
+    def test_container_name_not_set(self, sleep_mock, client_mock):
+        self.set_up_operator(
+            awslogs_group="awslogs-group",
+            awslogs_stream_prefix="prefix",
+            container_name=None,
+        )
+        client_mock.run_task.return_value = RESPONSE_WITHOUT_NAME
+        client_mock.describe_tasks.side_effect = [
+            {"tasks": [{"containers": []}]},
+            {"tasks": [{"containers": [{"name": "resolved-container"}]}]},
+        ]
+        self.ecs._start_task()
+        assert client_mock.describe_tasks.call_count == 2
+        assert self.ecs.container_name == "resolved-container"
+
+    @mock.patch.object(EcsBaseOperator, "client")
+    @mock.patch.object(EcsBaseOperator, "log")
+    @mock.patch("airflow.providers.amazon.aws.operators.ecs.sleep", return_value=None)
+    def test_container_name_resolution_fails_logs_message(self, sleep_mock, log_mock, client_mock):
+        self.set_up_operator(
+            awslogs_group="test-group",
+            awslogs_stream_prefix="prefix",
+            container_name=None,
+        )
+        client_mock.run_task.return_value = RESPONSE_WITHOUT_NAME
+        client_mock.describe_tasks.return_value = {"tasks": [{"containers": [{"name": None}]}]}
+
+        self.ecs._start_task()
+
+        assert client_mock.describe_tasks.call_count == 2
+        assert self.ecs.container_name is None
+        log_mock.info.assert_called_with(
+            "Could not find container name, required for the log stream after 2 tries"
+        )
+
+    @mock.patch.object(EcsBaseOperator, "client")
+    def test_container_name_not_polled(self, client_mock):
+        self.set_up_operator(
+            awslogs_group=None,
+            awslogs_stream_prefix=None,
+            container_name=None,
+        )
+        client_mock.run_task.return_value = RESPONSE_WITHOUT_NAME
+        self.ecs._start_task()
+        assert client_mock.describe_tasks.call_count == 0
+
 
 class TestEcsCreateClusterOperator(EcsBaseTestCase):
     @pytest.mark.parametrize("waiter_delay, waiter_max_attempts", WAITERS_TEST_CASES)
